Coverage report

Module | statements | missing | excluded | coverage
--- | --- | --- | --- | ---
.tox/cov/lib/python3.10/site-packages/confattr/__init__.py | 5 | 0 | 0 | 100%
.tox/cov/lib/python3.10/site-packages/confattr/config.py | 280 | 26 | 19 | 91%
.tox/cov/lib/python3.10/site-packages/confattr/configfile.py | 727 | 65 | 26 | 91%
.tox/cov/lib/python3.10/site-packages/confattr/subprocess_pipe.py | 32 | 2 | 0 | 94%
.tox/cov/lib/python3.10/site-packages/confattr/types.py | 112 | 24 | 1 | 79%
.tox/cov/lib/python3.10/site-packages/confattr/utils.py | 109 | 0 | 11 | 100%
Total | 1265 | 117 | 57 | 91%

No items found using the specified filter.